@@ -47,3 +47,8 @@ for project in Project.NAME.value:
     else:
         PROJECT_TO_API_KEYS = ProjectInfo(project, "AIR_API_KEY")
     PROJECTS_TO_API_KEYS[project] = PROJECT_TO_API_KEYS
+
+
+# GitHub/Lab constants
+gitlab_function_name_addition = "FUNCTION_NAME_ADDITION"
+gitlab_ci_project = "CI_PROJECT_NAME"
